.. module:: enaml.widgets.action_group

==========================
enaml.widgets.action_group
==========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    ActionGroup


.. autoclass:: ActionGroup
